@@ -1,6 +1,6 @@
 #ifndef lint
 static const char rcsid[] =
-    "@(#) $Id: cupdate.c 36 2013-11-15 00:08:37Z leres $ (LBL)";
+    "@(#) $Id: cupdate.c 37 2016-09-05 18:02:12Z leres $ (LBL)";
 #endif
 /*
  * Copyright (c) 2005, 2006, 2008, 2009, 2010
@@ -31,11 +31,11 @@ extern const char version[];
 
 /* Forwards */
 char *buildcommand(int, char **);
-void die(const char *, ...) __attribute__((noreturn, format (printf, 1, 2)));
+void __attribute__((noreturn, format (printf, 1, 2))) die(const char *, ...);
 void finish(void);
 char *runcommand(char *);
 int trimws(char *, int);
-void usage(void) __attribute__((noreturn));
+void __attribute__((noreturn)) usage(void);
 
 int
 main(int argc, char **argv)
@@ -48,13 +48,12 @@ main(int argc, char **argv)
 	const char *tty;
 	struct stat sbuf;
 
-	if (argv[0] == NULL)
-		prog = "gearratio";
-        else if ((cp = strrchr(argv[0], '/')) != NULL)
+        if ((cp = strrchr(argv[0], '/')) != NULL)
 		prog = cp + 1;
 	else
 		prog = argv[0];
 
+	opterr = 0;
 	while ((op = getopt(argc, argv, "dvw:")) != EOF)
 		switch (op) {
 
@@ -104,6 +103,8 @@ main(int argc, char **argv)
 	cbreak();
 	noecho();
 	clear();
+	/* Turn off cursor */
+	curs_set(0);
 	tv.tv_usec = 0;
 	for (;;) {
 		out = runcommand(cmd);
